;;**********************************************************************
;;**********************************************************************
;;
;; BPF2.ASM
;;
;; Assembler source for 2 Pole Switched Capacitor Band Pass Filter
;;
;; Rev A, 2002 MAR 30
;;
;; Copyright (c) 2001 Cypress Microsystems, Inc. All rights reserved.
;;
;;**********************************************************************
;;**********************************************************************
;;


export  BPF2_2_Start
export _BPF2_2_Start
export  BPF2_2_SetPower
export _BPF2_2_SetPower

export  BPF2_2_SetC1
export _BPF2_2_SetC1
export  BPF2_2_SetC2
export _BPF2_2_SetC2
export  BPF2_2_SetC3
export _BPF2_2_SetC3
export  BPF2_2_SetC4
export _BPF2_2_SetC4
export  BPF2_2_SetCA
export _BPF2_2_SetCA
export  BPF2_2_SetCB
export _BPF2_2_SetCB

export  BPF2_2_Stop
export _BPF2_2_Stop

;; -----------------------------------------------------------------
;;                         Register Definitions
;; -----------------------------------------------------------------
;; UM Cap value naming convention per Gregorian and Temes, p293 
;;
;;
;; * For a Mask/Val pair, this indicates that the value is
;;   determined by the user either through config-time parameteriza-
;;   tion or run-time manipulation.
;; BIT FIELD	         Mask/Val(hex)  Function
;; -----------------          ---- 	--------------------
;; FLFB: OUTPUT HALF                 BUILT IN SW-CAP B BLOCK
;; FLFB_CR0.OSZ              80/*  CB Cap Value (User parameter by table)
;; FLFB_CR0.CLOCK_PHASE      04/0  PHASE_NORM
;; FLFB_CR0.SIGN             02/0  POS 
;; FLFB_CR0.CAP_SIZE         1F/*  A-cap: C3 Cap Value (User parameter)
;;
;; FLFB_CR1.SCB_INPUT_MUX_A  E0/*  (Input selection by placement)		
;; FLFB_CR1.CAP_SIZE         1F/0  B-cap: (set to 0 in LPF)
;; FLFB_CR2.A_OUT            80/*  Output En. (User parameter, default DISABLE)
;;
;; FLFB_CR2.COMP_OUT         40/0  DISABLED
;; FLFB_CR2.AZ_PHASE         20/1  AZ_PH1
;; FLFB_CR2.CAP_SIZE         1F/*  C-cap: C4 Cap Value (User parameter)
;;
;; FLFB_CR3.REF_SELECT       C0/0  Ref to AGND
;; FLFB_CR3.FB_CAP_SELECT    20/1  PH2_AZ_ENABLE
;; FLFB_CR3.FB_CAP_GND       10/0  DISABLED
;; FLFB_CR3.SBB              08/0  DISABLED
;; FLFB_CR3.SCB_INPUT_MUX_B  04/1  IN2B
;; FLFB_CR3.PWR_SELECT       03/0  Power OFF at start-up
;;
;; FLIN: INPUT HALF OF FILTER, BUILT IN SW-CAP A BLOCK
;; FLIN_CR0.OSZ               80/*  CA Cap Value (User parameter)
;; FLIN_CR0.CLOCK_PHASE       04/0  PHASE_NORM
;; FLIN_CR0.SIGN              02/1  NEG 
;; FLIN_CR0.CAP_SIZE          1F/*  A-cap: C1 Cap Value (User parameter)
;;
;; FLIN_CR1.SCB_INPUT_MUX_A_C E0/*  Input selection (User parameter)		
;; FLIN_CR1.CAP_SIZE          1F/*  B-cap: C2 Cap Value (User parameter)
;;
;; FLIN_CR2.A_OUT             80/0  DISABLED
;; FLIN_CR2.COMP_OUT          40/0  DISABLED
;; FLIN_CR2.AZ_PHASE          20/1  AZ_PH2
;; FLIN_CR2.CAP_SIZE          1F/0  C-cap: (set to 0 in LPF)
;;
;; FLIN_CR3.REF_SELECT        C0/0  Ref to AGND
;; FLIN_CR3.FB_CAP_SELECT     20/1  PH2_AZ_ENABLE
;; FLIN_CR3.FB_CAP_GND        10/0  DISABLED
;; FLIN_CR3.SCA_INPUT_MUX_B   0C/*  Conn to FLFB-output (placement)
;; FLIN_CR3.PWR_SELECT        03/0  Power OFF at start-up

include "BPF2_2.inc"
include "m8c.inc"
POWERMASK:           equ   03h      ;Power field mask for CR3
BPF_CNUMMASK:        equ   1fh
BPF_CFBMASK:         equ   80h

;; -----------------------------------------------------------------
;; Start/SetPower - Applies power setting to the module's PSoC blocks
;; 
;; INPUTS: A contains the power setting 0=Off, 1=Low, 2=Med, 3=High
;; OUTUTS: None
;; -----------------------------------------------------------------

 BPF2_2_Start:
_BPF2_2_Start:
 BPF2_2_SetPower:
_BPF2_2_SetPower:

    and A, POWERMASK                         ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
;
    push A                                   ; put power value in temp store
    mov A, reg[BPF2_2_FLIN_CR3]    ; read power value
    and A, ~POWERMASK                        ; clear power bits in A
    or  A, [X]                               ; combine power value with balance of reg.
    mov reg[BPF2_2_FLIN_CR3], A    ; move complete value back to register
;
    mov A, reg[BPF2_2_FLFB_CR3]   ; read power value
    and A, ~POWERMASK                        ; clear power bits in A
    or  A, [X]                               ; combine power value with balance of reg.
    mov reg[BPF2_2_FLFB_CR3], A   ; move complete value back to register
    pop A
    ret

;; -----------------------------------------------------------------
;; SetC(x): Applies cap value to specific location in filter
;; 
;; INPUTS: A contains the cap value
;;         Cap value is 1 to 31 for C1, C2, C3, C4
;;         Cap value contained in equate for CA, CB
;; OUTUTS: None
;; -----------------------------------------------------------------

 BPF2_2_SetC1:
_BPF2_2_SetC1:

    and A, BPF_CNUMMASK                        ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
    push A                                   ; put C1 value in temp store
    mov A, reg[BPF2_2_FLIN_CR0]    ; read current C1
    and A, ~BPF_CNUMMASK                       ; clear C1 bits in A
    or  A, [X]                               ; combine C1 value with balance of reg.
    mov reg[BPF2_2_FLIN_CR0], A    ; move complete value back to register
    pop  A
    ret

 BPF2_2_SetC2:
_BPF2_2_SetC2:

    and A, BPF_CNUMMASK                       ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
    push A                                   ; put C2 value in temp store
    mov A, reg[BPF2_2_FLIN_CR1]    ; read current C2
    and A, ~BPF_CNUMMASK                       ; clear C2 bits in A
    or  A, [X]                               ; combine C2 value with balance of reg.
    mov reg[BPF2_2_FLIN_CR1], A    ; move complete value back to register
    pop A
    ret

 BPF2_2_SetC3:
_BPF2_2_SetC3:

    and A, BPF_CNUMMASK                        ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
    push A                                   ; put C3 value in temp store
    mov A, reg[BPF2_2_FLFB_CR0]    ; read current C3
    and A, ~BPF_CNUMMASK                       ; clear C3 bits in A
    or  A, [X]                               ; combine C3 value with balance of reg.
    mov reg[BPF2_2_FLFB_CR0], A    ; move complete value back to register
    pop A
    ret

 BPF2_2_SetC4:
_BPF2_2_SetC4:

    and A, BPF_CNUMMASK                        ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
    push A                                   ; put C4 value in temp store
    mov A, reg[BPF2_2_FLFB_CR0]    ; read current C4
    and A, ~BPF_CNUMMASK                       ; clear C4 bits in A
    or  A, [X]                               ; combine C4 value with balance of reg.
    mov reg[BPF2_2_FLFB_CR0], A    ; move complete value back to register
    pop A
    ret

 BPF2_2_SetCA:
_BPF2_2_SetCA:

    and A, BPF_CFBMASK                        ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
    push A                                   ; put CA value in temp store
    mov A, reg[BPF2_2_FLIN_CR0]    ; read current CA
    and A, ~BPF_CFBMASK                       ; clear CA bits in A
    or  A, [X]                               ; combine CA value with balance of reg.
    mov reg[BPF2_2_FLIN_CR0], A    ; move complete value back to register
    pop A
    ret

 BPF2_2_SetCB:
_BPF2_2_SetCB:

    and A, BPF_CFBMASK                        ; mask A to protect unchanged bits
    mov X, SP                                ; define temp store location
    push A                                   ; put CB value in temp store
    mov A, reg[BPF2_2_FLFB_CR0]    ; read current CB
    and A, ~BPF_CFBMASK                       ; clear CB bits in A
    or  A, [X]                               ; combine CB value with balance of reg.
    mov reg[BPF2_2_FLFB_CR0], A    ; move complete value back to register
    pop A
    ret

;; -----------------------------------------------------------------
;; Stop - Cuts power to the user module.
;;
;; INPUTS:  None
;; OUTPUTS: None
;; -----------------------------------------------------------------
 BPF2_2_Stop:
_BPF2_2_Stop:

        
    and reg[BPF2_2_FLIN_CR3], ~POWERMASK
    and reg[BPF2_2_FLFB_CR3], ~POWERMASK
    ret
